Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NewsClient ¶
type NewsClient struct {
// Available locales:
// en-us, ko-kr, fr-fr, es-es, es-mx, de-de, it-it, pl-pl,
// pt-br, tr-tr, ru-ru, ja-jp, en-sg, zh-tw, th-th, vi-vn
Locale string
}
A client that allows to get official Legends of Runeterra news
type NewsEntry ¶
type NewsEntry struct {
UID string `json:"uid"`
Authors []string `json:"authors"`
Categories []string `json:"categories"`
Date time.Time `json:"date"`
Description string `json:"description"`
Image string `json:"image"`
Tags []string `json:"tags"`
Title string `json:"title"`
URL string `json:"url"`
}
Legends of Runeterra news entry.
type StatusClient ¶
type StatusClient struct {
// Available regions:
// americas, apac, europe
Region string
}
A client that allows to get Legends of Runeterra server status.
Source - https://status.riotgames.com/lor
func (StatusClient) GetItems ¶
func (client StatusClient) GetItems(locale string) ([]StatusEntry, error)
Available locales: en-US, de-DE, es-ES, es-MX, fr-FR, it-IT, ja-JP, ko-KR, pl-PL, pt-BR, ru-RU, th-TH, tr-TR, vi-VN, zh-TW.
Click to show internal directories.
Click to hide internal directories.