Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type JobsClient ¶
type JobsClient struct {
// Available locales:
// en, id, ms, pt-br, cs, fr, de, el, hu, it, ja, ko,
// es-419, pl, ro, ru, zh-cn, es, th, zh-hant, tr, vi
Locale string
}
A client that allows to get a list of available vacancies in Riot games.
Source - https://www.riotgames.com/en/work-with-us
func (JobsClient) GetItems ¶
func (client JobsClient) GetItems() ([]JobsEntry, error)
type JobsCraftEntry ¶
type JobsCraftEntry struct {
ID string `json:"id"`
Name string `json:"name"`
More string `json:"more"`
}
Riot Games craft entry.
type JobsEntry ¶
type JobsEntry struct {
UID string `json:"uid"`
Craft JobsCraftEntry `json:"craft"`
Office JobsOfficeEntry `json:"office"`
Products string `json:"products"`
Title string `json:"title"`
URL string `json:"url"`
}
Riot Games jobs entry.
type JobsOfficeEntry ¶
type JobsOfficeEntry struct {
ID string `json:"id"`
Name string `json:"name"`
More string `json:"more"`
URL string `json:"url"`
}
Riot Games office entry.
type NewsClient ¶
type NewsClient struct {
// Available locales:
// en, id, ms, pt-br, cs, fr, de, el, hu, it, ja, ko,
// es-419, pl, ro, ru, zh-cn, es, th, zh-hant, tr, vi
Locale string
}
A client that allows to get official RiotGames news.
Source - https://www.riotgames.com/en/news
Click to show internal directories.
Click to hide internal directories.